@@ -3,6 +3,7 @@ from kadmin._lib import (
     EncryptionType,
     KAdmin,
     KAdminApiVersion,
+    KAdminPrivileges,
     KeySalt,
     KeySalts,
     NewPrincipalKey,
@@ -21,6 +22,7 @@ __all__ = (
     "EncryptionType",
     "KAdmin",
     "KAdminApiVersion",
+    "KAdminPrivileges",
     "KeySalt",
     "KeySalts",
     "NewPrincipalKey",
